@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ * SPDX-FileCopyrightText: 2019-2025 Mattia Basaglia <dev@dragon.best>
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -26,7 +26,7 @@ private:
         file.write(lottie::LottieHtmlFormat::html_head(this, comp, {}));
         file.write("<body><div id='animation'>");
         SvgRenderer rend(SMIL, CssFontType::FontFace);
-        rend.write_main(comp);
+        rend.write_main(comp, comp->document()->current_time());
         rend.write(&file, true);
         file.write("</div></body></html>");
         return true;
