@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ * SPDX-FileCopyrightText: 2019-2025 Mattia Basaglia <dev@dragon.best>
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -77,7 +77,7 @@ static QByteArray frame_to_svg(model::Composition* comp)
     file.open(QIODevice::WriteOnly);
 
     io::svg::SvgRenderer rend(io::svg::NotAnimated, io::svg::CssFontType::FontFace);
-    rend.write_main(comp);
+    rend.write_main(comp, comp->document()->current_time());
     rend.write(&file, true);
 
     return data;
